@@ -1,6 +1,6 @@
 package Net::Appliance::Session;
-{
-  $Net::Appliance::Session::VERSION = '3.122020_001';
+BEGIN {
+  $Net::Appliance::Session::VERSION = '3.111530';
 }
 
 use Moose;
@@ -8,7 +8,6 @@ use Net::CLI::Interact;
 
 with 'Net::Appliance::Session::Transport';
 with 'Net::Appliance::Session::Engine';
-with 'Net::Appliance::Session::Async';
 
 foreach my $slot (qw/
     logged_in
@@ -43,7 +42,6 @@ foreach my $slot (qw/
 foreach my $slot (qw/
     username
     password
-    privileged_password
 /) {
     has $slot => (
         is => 'rw',
@@ -51,7 +49,6 @@ foreach my $slot (qw/
         required => 0,
         reader => "get_$slot",
         writer => "set_$slot",
-        predicate => "has_$slot",
     );
 }
 
@@ -69,7 +66,6 @@ foreach my $slot (qw/
 foreach my $slot (qw/
     host
     app
-    add_library
 /) {
     has $slot => (
         is => 'ro',
@@ -81,7 +77,7 @@ foreach my $slot (qw/
 
 has 'connect_options' => (
     is => 'ro',
-    isa => 'HashRef',
+    isa => 'HashRef[Str]',
     required => 0,
     default => sub { {} },
 );
@@ -93,7 +89,6 @@ has 'nci' => (
     handles => [qw/
         cmd
         macro
-        last_prompt
         last_response
         set_phrasebook
         set_global_log_at
@@ -107,17 +102,12 @@ sub _build_nci {
     $self->connect_options->{host} = $self->host
         if $self->has_host;
 
-    my $nci = Net::CLI::Interact->new({
+    return Net::CLI::Interact->new({
         transport => $self->transport,
         personality => $self->personality,
         connect_options => $self->connect_options,
         ($self->has_app ? (app => $self->app) : ()),
-        ($self->has_add_library ? (add_library => $self->add_library) : ()),
     });
-
-    $nci->logger->log('engine', 'notice',
-        sprintf "NAS loaded, version %s", ($Net::Appliance::Session::VERSION || 'devel'));
-    return $nci;
 }
 
 1;
@@ -134,13 +124,13 @@ Net::Appliance::Session - Run command-line sessions to network appliances
 
 =head1 VERSION
 
-version 3.122020_001
+version 3.111530
 
 =head1 IMPORTANT NOTE ABOUT UPGRADING FROM VERSION 2.x
 
 Between version 2.x and 3.x of this module the programmer's interface changed
 in a number of ways. If you have existing code to migrate to this new version,
-please see the L<Upgrading|Net::Appliance::Session::APIv2>
+please see the L<Upgrading|Net::Appliance::Session::Manual::Upgrading>
 document which details all steps necessary.
 
 =head1 SYNOPSIS
@@ -148,7 +138,7 @@ document which details all steps necessary.
  use Net::Appliance::Session;
  
  my $s = Net::Appliance::Session->new({
-     personality => 'ios',
+     personality => 'cisco',
      transport => 'SSH',
      host => 'hostname.example',
      privileged_paging => 1, # only if using ASA/PIX OS 7+
@@ -156,9 +146,9 @@ document which details all steps necessary.
  });
  
  eval {
-     $s->connect({ username => 'username', password => 'loginpass' });
+     $s->connect({name => 'username', password => 'loginpass'});
  
-     $s->begin_privileged({ password => 'privilegedpass' });
+     $s->begin_privileged('privilegedpass');
      print $s->cmd('show access-list');
      $s->end_privileged;
  };
@@ -175,9 +165,10 @@ network appliance. There is special support for moving into "privileged" mode
 and "configure" mode, along with the ability to send commands to the connected
 device and retrieve returned output.
 
-There are other CPAN modules that cover similar ground, but they are less
-robust and do not handle native SSH, Telnet and Serial Line connections with a
-single interface on both Unix and Windows platforms.
+There are other CPAN modules that cover similar ground, including Net::SSH and
+Net::Telnet::Cisco, but they are less robust or do not handle native SSH,
+Telnet and Serial Line connections with a single interface on both Unix and
+Windows platforms.
 
 Built-in commands come from a phrasebook which supports many network device
 vendors (Cisco, HP, etc) or you can install a new phrasebook. Most phases of
@@ -185,15 +176,15 @@ the connection are configurable for different device behaviours.
 
 =head1 METHODS
 
-As in the synopsis above, the first step is to create a new instance.
-Recommended practice is to wrap all other method calls in a Perl C<eval> block
-to catch errors (typically time-outs waiting for CLI response). For a
-demonstration of usage, see the example script shipped with this distribution.
+As in the synopsis above, the first step is to create a new instance. As in
+the synopsis above, recommended practice is to wrap all other method calls in
+a Perl C<eval> block to catch errors (typically time-outs waiting for CLI
+response).
 
 =head2 Net::Appliance::Session->new( \%options )
 
  my $s = Net::Appliance::Session->new({
-     personality => 'ios',
+     personality => 'cisco',
      transport => 'SSH',
      host => 'hostname.example',
  });
@@ -206,9 +197,10 @@ options are required, others optional:
 =item C<< personality => $name >> (required)
 
 Tells the module which "language" to use when talking to the connected device,
-for example C<ios> for Cisco IOS devices. There's a list of all the supported
-platforms in the L<Phrasebook|Net::CLI::Interact::Manual::Phrasebook>
-documentation. It's also possible to write new phrasebooks.
+for example C<cisco> for Cisco IOS devices. There's a list of all the
+supported platforms in the
+L<Phrasebook|Net::CLI::Interact::Manual::Phrasebook> documentation. It's also
+possible to write new phrasebooks.
 
 =item C<< transport => $backend >> (required)
 
@@ -231,18 +223,7 @@ name of the target device in this parameter.
 
 Some of the transport backends can take their own options. For example with a
 serial line connection you might specify the port speed, etc. See the
-respective manual pages for each transport backend for further details
-(L<SSH|Net::CLI::Interact::Transport::SSH>,
-L<Telnet|Net::CLI::Interact::Transport::Telnet>,
-L<Serial|Net::CLI::Interact::Transport::Serial>).
-
-=item C<< add_library => $directory >>
-
-If you've added to the built-in phrasebook with your own macros, then use
-this option to load your new phrasebook file(s). The path here should be the
-root within which the personality is installed, such as:
-
- ${directory}/cisco/ios/pb
+respective manual pages for each transport backend for further details.
 
 =back
 
@@ -276,18 +257,9 @@ how the device is configured, and how you have configured this module to act.
 If it looks like the device presented a Username prompt. and you don't pass
 the username a Perl exception will be thrown.
 
-The password is cached within the module for possible use later on when
+The password is cached within the module for possbible use later on when
 entering "privileged" mode.
 
-=item C<< privileged_password => $secret >> (optional)
-
-In the situation where you've activated "privileged paging", yet your device
-uses a different password for privileged mode than login, you'll need to set
-that other password here.
-
-Otherwise, because the module tries to disable paging, it first goes into
-privileged mode as you instructed, and fails with the wrong (login) password.
-
 =back
 
 =head2 begin_privileged and end_privileged
@@ -330,29 +302,15 @@ Execute a single command statement on the connected device. The statement is
 executed verbatim on the device, with a newline appended.
 
 In scalar context the response is returned as a single string. In list context
-the gathered response is returned as a list of lines. In both cases your local
-platform's newline character will end all lines.
-
-You can also call the C<last_response> method which returns the same data with
-the same contextual behaviour.
-
-This method accepts a hashref of options following the C<$command>, which can
-include a C<timeout> value to permit long running commands to have all their
-output gathered.
+the gathered response is returned, only split into a list so that each line is
+one item.
 
 To handle more complicated interactions, for example commands which prompt for
 confirmation or optional parameters, you should use a Macro. These are set up
 in the phrasebook and issued via the C<< $s->macro($name) >> method call. See
-the L<Phrasebook|Net::CLI::Interact::Phrasebook> and
-L<Cookbook|Net::CLI::Interact::Manual::Cookbook> manual pages for further
-details.
-
-If you receive response text with a "mangled" copy of the issued command at
-the start, then it's likely you need to set the terminal width. This prevents
-the connected device from line-wrapping long commands. Issue something like:
-
- $s->begin_privileged;
- $s->cmd('terminal width 512');
+the L<Phrasebook|Net::CLI::Interact::Phrasebook#PHRASEBOOK_FORMAT> and
+L<Cookbook|Net::CLI::Interact::Manual::Cookbook#Macros> manual pages for
+further details.
 
 =head2 close
 
@@ -362,10 +320,6 @@ Once you have finished work with the device, call this method. It attempts to
 back out of any "privileged" or "configuration" mode you've entered, re-enable
 paging (unless suppressed) and then disconnect.
 
-If a macro named C<"disconnect"> exists in the loaded phrasebook then it's
-called just before disconnection. This allows you to issue a command such as
-C<"exit"> to cleanly log out.
-
 =head1 CONFIGURATION
 
 Each of the entries below may either be passed as a parameter in the options
@@ -429,33 +383,12 @@ behaviour.
 
 =back
 
-=head1 ASYNCHRONOUS BEHAVIOUR
-
-The standard, and recommended way to use this module is as above, whereby the
-application is blocked waiting for command response. It's also possible to
-send a command, and separately return to ask for output at a later time.
-
- $s->say('show clock');
-
-This will send the command C<show clock> to the connected device, followed by
-a newline character.
-
- $s->gather();
-
-This will gather and return output, with similar behaviour to C<cmd()>, above.
-That is, it blocks waiting for output and a prompt, will timeout, and accepts
-the same options.
-
-You can still use C<last_response> after calling C<gather>, however be aware
-that the command (from C<say>) may be echoed at the start of the output,
-depending on device and connection transport.
-
 =head1 DIAGNOSTICS
 
 To see a log of all the processes within this module, and a copy of all data
 sent to and received from the device, call the following method:
 
- $s->set_global_log_at('debug');
+ $s->set_global_log_at( 'debug' );
 
 In place of C<debug> you can have other log levels, and via the embedded
 L<Logger|Net::CLI::Interact::Logger> at C<< $s->nci->logger >> it's possible
@@ -465,26 +398,13 @@ to finely control the diagnostics.
 
 See L<Net::CLI::Interact>.
 
-=head1 THANKS
-
-The following people have kindly reported bugs with patches or contributed to
-the development in some other way:
-
-=over 4
-
-=item *
-
-Carlos Vicente
-
-=back
-
 =head1 AUTHOR
 
 Oliver Gorwits <oliver@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Oliver Gorwits.
+This software is copyright (c) 2011 by Oliver Gorwits.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
