@@ -1,6 +1,6 @@
 package Net::Appliance::Session::Engine;
-{
-  $Net::Appliance::Session::Engine::VERSION = '3.122020_001';
+BEGIN {
+  $Net::Appliance::Session::Engine::VERSION = '3.111530';
 }
 
 use Moose::Role;
@@ -28,10 +28,7 @@ sub enable_paging {
     my $privstate = $self->in_privileged_mode;
     $self->begin_privileged if $self->privileged_paging;
 
-    my $pagercmd = ($self->nci->phrasebook->has_macro('enable_paging')
-        ? 'enable_paging' : 'paging');
-
-    $self->macro($pagercmd, { params => [
+    $self->macro('paging', { params => [
         $self->pager_enable_lines
     ]} );
 
@@ -48,10 +45,7 @@ sub disable_paging {
     my $privstate = $self->in_privileged_mode;
     $self->begin_privileged if $self->privileged_paging;
 
-    my $pagercmd = ($self->nci->phrasebook->has_macro('disable_paging')
-        ? 'disable_paging' : 'paging');
-
-    $self->macro($pagercmd, { params => [
+    $self->macro('paging', { params => [
         $self->pager_disable_lines
     ]} );
 
@@ -82,11 +76,7 @@ sub begin_privileged {
 
     # default is to re-use login credentials
     my $username = $options->has_username ? $options->username : $self->get_username;
-
-    # rt.cpan#69139 support passing of privileged_password to the constructor
-    my $password = $options->has_password ? $options->password :
-                   $self->has_privileged_password ? $self->get_privileged_password
-                                                               : $self->get_password;
+    my $password = $options->has_password ? $options->password : $self->get_password;
 
     $self->macro('begin_privileged');
 
